@@ -20,14 +20,47 @@ import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
 
+/**
+ * Contains logic to work with extra-info descriptor files.
+ *
+ * <p>The extra-info document format is defined in the dir-spec
+ * document.</p>
+ *
+ * @see <a href="https://github.com/torproject/torspec/blob/main/dir-spec.txt#L893">dir-spec.txt</a>
+ *
+ * <p>Descriptor keys are defined and their occurency is checked to
+ * make sure the descriptor file format is valid.</p>
+ *
+ * <p>Descriptor lines are parsed and their values can be accessed
+ * through the defined methods.</p>
+ *
+ * <p>When metrics library learns how to parse a new line for extra-info
+ * descriptor files all its fields, from the dir-spec document, are
+ * parsed in this class.</p>
+ *
+ * <p>The new key is added to {@link Key} and its occurence is checked in
+ * {@link ExtraInfoDescriptorImpl} constructor.</p>
+ *
+ * @since 1.0.0
+ */
+
+
 public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
     implements ExtraInfoDescriptor {
 
   private static final long serialVersionUID = -4720810362228341775L;
 
+  /**
+   * Define keys that MUST occur exactly one time in every
+   * instance of the document type.
+   */
   private Set<Key> exactlyOnceKeys = EnumSet.of(
       Key.EXTRA_INFO, Key.PUBLISHED);
 
+  /**
+   * Define keys that MAY occur zero or one times in any instance of the
+   * document type, but MUST NOT occur more than once.
+   */
   private static final Set<Key> atMostOnceKeys = EnumSet.of(
       Key.IDENTITY_ED25519, Key.MASTER_KEY_ED25519, Key.READ_HISTORY,
       Key.WRITE_HISTORY, Key.DIRREQ_READ_HISTORY, Key.DIRREQ_WRITE_HISTORY,
@@ -41,6 +74,11 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
     super(descriptorBytes, offsetAndLimit, descriptorFile, false);
     this.parseDescriptorBytes();
     this.checkExactlyOnceKeys(exactlyOnceKeys);
+
+    /**
+     * When a key is added to {@link Key} it needs to be added here too.
+     * Either directly or to the methods that check the occurrence of the key.
+     */
     Set<Key> dirreqStatsKeys = EnumSet.of(
         Key.DIRREQ_STATS_END, Key.DIRREQ_V2_IPS, Key.DIRREQ_V3_IPS,
         Key.DIRREQ_V2_REQS, Key.DIRREQ_V3_REQS, Key.DIRREQ_V2_SHARE,
@@ -74,6 +112,12 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
     this.clearParsedKeys();
   }
 
+  /**
+   * Parse the descriptor file.
+   *
+   * @throws DescriptorParseException
+   *
+   */
   private void parseDescriptorBytes() throws DescriptorParseException {
     Scanner scanner = this.newScanner().useDelimiter(NL);
     Key nextCrypto = Key.EMPTY;
@@ -789,7 +833,7 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
     try {
-      this.hidservRendRelayedCells = Double.parseDouble(partsNoOpt[1]);
+      this.hidservRendRelayedCells = Long.parseLong(partsNoOpt[1]);
     } catch (NumberFormatException e) {
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
@@ -805,7 +849,7 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
     try {
-      this.hidservDirOnionsSeen = Double.parseDouble(partsNoOpt[1]);
+      this.hidservDirOnionsSeen = Long.parseLong(partsNoOpt[1]);
     } catch (NumberFormatException e) {
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
@@ -829,7 +873,7 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
     try {
-      this.hidservRendV3RelayedCells = Double.parseDouble(partsNoOpt[1]);
+      this.hidservRendV3RelayedCells = Long.parseLong(partsNoOpt[1]);
     } catch (NumberFormatException e) {
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
@@ -845,7 +889,7 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
     try {
-      this.hidservDirV3OnionsSeen = Double.parseDouble(partsNoOpt[1]);
+      this.hidservDirV3OnionsSeen = Long.parseLong(partsNoOpt[1]);
     } catch (NumberFormatException e) {
       throw new DescriptorParseException("Illegal line '" + line + "'.");
     }
@@ -997,7 +1041,7 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
   private int overloadRatelimitsVersion = 0;
 
   @Override
-  public long getOverloadRatelimitsVersion() {
+  public int getOverloadRatelimitsVersion() {
     return this.overloadRatelimitsVersion;
   }
 
@@ -1435,10 +1479,10 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
     return this.hidservStatsIntervalLength;
   }
 
-  private Double hidservRendRelayedCells;
+  private long hidservRendRelayedCells;
 
   @Override
-  public Double getHidservRendRelayedCells() {
+  public long getHidservRendRelayedCells() {
     return this.hidservRendRelayedCells;
   }
 
@@ -1450,10 +1494,10 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
         : new HashMap<>(this.hidservRendRelayedCellsParameters);
   }
 
-  private Double hidservDirOnionsSeen;
+  private long hidservDirOnionsSeen;
 
   @Override
-  public Double getHidservDirOnionsSeen() {
+  public long getHidservDirOnionsSeen() {
     return this.hidservDirOnionsSeen;
   }
 
@@ -1479,10 +1523,10 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
     return this.hidservV3StatsIntervalLength;
   }
 
-  private Double hidservRendV3RelayedCells;
+  private long hidservRendV3RelayedCells;
 
   @Override
-  public Double getHidservRendV3RelayedCells() {
+  public long getHidservRendV3RelayedCells() {
     return this.hidservRendV3RelayedCells;
   }
 
@@ -1494,10 +1538,10 @@ public abstract class ExtraInfoDescriptorImpl extends DescriptorImpl
         : new HashMap<>(this.hidservRendV3RelayedCellsParameters);
   }
 
-  private Double hidservDirV3OnionsSeen;
+  private long hidservDirV3OnionsSeen;
 
   @Override
-  public Double getHidservDirV3OnionsSeen() {
+  public long getHidservDirV3OnionsSeen() {
     return this.hidservDirV3OnionsSeen;
   }
 
