@@ -1,4 +1,4 @@
-/* Copyright 2011--2018 The Tor Project
+/* Copyright 2011--2020 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.impl;
@@ -141,9 +141,8 @@ public class RelayNetworkStatusConsensusImplTest {
         sb.append(this.voteDigestLine).append("\n");
       }
       String dirSourceWithTrailingNewLine = sb.toString();
-      String dirSource = dirSourceWithTrailingNewLine.substring(0,
+      return dirSourceWithTrailingNewLine.substring(0,
           dirSourceWithTrailingNewLine.length() - 1);
-      return dirSource;
     }
   }
 
@@ -299,9 +298,8 @@ public class RelayNetworkStatusConsensusImplTest {
         sb.append(this.pLine).append("\n");
       }
       String statusEntryWithTrailingNewLine = sb.toString();
-      String statusEntry = statusEntryWithTrailingNewLine.substring(0,
+      return statusEntryWithTrailingNewLine.substring(0,
           statusEntryWithTrailingNewLine.length() - 1);
-      return statusEntry;
     }
   }
 
@@ -339,7 +337,7 @@ public class RelayNetworkStatusConsensusImplTest {
     }
 
     private String buildDirectorySignature() {
-      String directorySignature = "directory-signature " + identity + " "
+      return "directory-signature " + identity + " "
           + signingKey + "\n"
           + "-----BEGIN SIGNATURE-----\n"
           + "gE64+/4BH43v1+7jS9FK1tu2+94at8xhVSPn4O/PpOx7b0Yb+S1hac1QHAiS"
@@ -348,7 +346,6 @@ public class RelayNetworkStatusConsensusImplTest {
                 + "P3JG\n"
           + "z89A+wrsN17I5490y66AEvws54BYZMbgRfp8HXn/0Ss=\n"
           + "-----END SIGNATURE-----";
-      return directorySignature;
     }
   }
 
@@ -368,6 +365,7 @@ public class RelayNetworkStatusConsensusImplTest {
     assertTrue(consensus.getRecommendedServerVersions().contains(
         "0.2.3.8-alpha"));
     assertTrue(consensus.getKnownFlags().contains("Running"));
+    assertTrue(consensus.getKnownFlags().contains("MiddleOnly"));
     assertTrue(consensus.getRecommendedClientProtocols().get("Cons")
         .contains(1L));
     assertFalse(consensus.getRecommendedRelayProtocols().get("Cons")
@@ -796,7 +794,7 @@ public class RelayNetworkStatusConsensusImplTest {
     RelayNetworkStatusConsensus consensus = ConsensusBuilder
         .createWithRecommendedClientProtocolsLine(
         "recommended-client-protocols Cons=1,2,3");
-    assertEquals(new TreeSet<Long>(Arrays.asList(new Long[] { 1L, 2L, 3L })),
+    assertEquals(new TreeSet<>(Arrays.asList(1L, 2L, 3L)),
         consensus.getRecommendedClientProtocols().get("Cons"));
   }
 
@@ -806,7 +804,7 @@ public class RelayNetworkStatusConsensusImplTest {
     RelayNetworkStatusConsensus consensus = ConsensusBuilder
         .createWithRecommendedRelayProtocolsLine(
         "recommended-relay-protocols Cons=1,3-4");
-    assertEquals(new TreeSet<Long>(Arrays.asList(new Long[] { 1L, 3L, 4L })),
+    assertEquals(new TreeSet<>(Arrays.asList(1L, 3L, 4L)),
         consensus.getRecommendedRelayProtocols().get("Cons"));
   }
 
@@ -816,8 +814,8 @@ public class RelayNetworkStatusConsensusImplTest {
     RelayNetworkStatusConsensus consensus = ConsensusBuilder
         .createWithRequiredClientProtocolsLine(
         "required-client-protocols Cons=1-3,2-4");
-    assertEquals(new TreeSet<Long>(Arrays.asList(
-        new Long[] { 1L, 2L, 3L, 4L })),
+    assertEquals(new TreeSet<>(Arrays.asList(
+        1L, 2L, 3L, 4L)),
         consensus.getRequiredClientProtocols().get("Cons"));
   }
 
@@ -827,7 +825,7 @@ public class RelayNetworkStatusConsensusImplTest {
     RelayNetworkStatusConsensus consensus = ConsensusBuilder
         .createWithRequiredRelayProtocolsLine(
         "required-relay-protocols Cons=1-1,1-1");
-    assertEquals(new TreeSet<Long>(Arrays.asList(new Long[] { 1L })),
+    assertEquals(new TreeSet<>(Arrays.asList(1L)),
         consensus.getRequiredRelayProtocols().get("Cons"));
   }
 
@@ -1639,4 +1637,3 @@ public class RelayNetworkStatusConsensusImplTest {
     assertEquals(unrecognizedLines, consensus.getUnrecognizedLines());
   }
 }
-
