@@ -33,7 +33,7 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
       Key.IPV6_POLICY, Key.NTOR_ONION_KEY, Key.ONION_KEY_CROSSCERT,
       Key.NTOR_ONION_KEY_CROSSCERT, Key.TUNNELLED_DIR_SERVER,
       Key.ROUTER_SIG_ED25519, Key.ROUTER_SIGNATURE, Key.ROUTER_DIGEST_SHA256,
-      Key.ROUTER_DIGEST, Key.BRIDGE_DISTRIBUTION_REQUEST);
+      Key.ROUTER_DIGEST, Key.BRIDGE_DISTRIBUTION_REQUEST, Key.FAMILY_CERT);
 
   private static final Set<Key> exactlyOnce = EnumSet.of(
       Key.ROUTER, Key.BANDWIDTH, Key.PUBLISHED);
@@ -163,6 +163,10 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
         case NTOR_ONION_KEY:
           this.parseNtorOnionKeyLine(line, partsNoOpt);
           break;
+        case FAMILY_CERT:
+          this.parseFamilyCertLine(line, partsNoOpt);
+          nextCrypto = key;
+          break;
         case IDENTITY_ED25519:
           this.parseIdentityEd25519Line(line, partsNoOpt);
           nextCrypto = key;
@@ -219,6 +223,9 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
             case NTOR_ONION_KEY_CROSSCERT:
               this.ntorOnionKeyCrosscert = cryptoString;
               break;
+            case FAMILY_CERT:
+              this.familyCert = cryptoString;
+              break;
             default:
               if (this.unrecognizedLines == null) {
                 this.unrecognizedLines = new ArrayList<>();
@@ -437,10 +444,10 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
           String separator = partsNoOpt[i].contains("=") ? "=" : "~";
           String fingerprint = ParseHelper.parseTwentyByteHexString(line,
               partsNoOpt[i].substring(1, partsNoOpt[i].indexOf(
-              separator)));
+                  separator)));
           String nickname = ParseHelper.parseNickname(line,
               partsNoOpt[i].substring(partsNoOpt[i].indexOf(
-              separator) + 1));
+                  separator) + 1));
           familyEntries[i - 1] = "$" + fingerprint + separator + nickname;
         } else {
           familyEntries[i - 1] = "$"
@@ -614,6 +621,13 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     }
   }
 
+  private void parseFamilyCertLine(String line,
+      String[] partsNoOpt) throws DescriptorParseException {
+    if (partsNoOpt.length != 1) {
+      throw new DescriptorParseException("Illegal line '" + line + "'.");
+    }
+  }
+
   private void parseOnionKeyCrosscert(String line,
       String[] partsNoOpt) throws DescriptorParseException {
     if (partsNoOpt.length != 1) {
@@ -960,6 +974,13 @@ public abstract class ServerDescriptorImpl extends DescriptorImpl
     return this.identityEd25519;
   }
 
+  private String familyCert;
+
+  @Override
+  public String getFamilyCert() {
+    return this.familyCert;
+  }
+
   private String masterKeyEd25519;
 
   @Override
